***this file creates the CR_database***;

#delimit;
clear;
set more off;
set mem 200m;
set matsize 300;


use C:\Alon\CR_migration\migration.dta;

gen home=(scode==hcode);

joinby scode using C:\Alon\CR_migration\S_domestic_labor.dta,unm(both);
drop _m scountry;

sort scode hcode;

********************************************;
******************general*******************;
********************************************;

gen pcode=scode*hcode;

gen developing=(scode==213|scode==223|scode==228|scode==924|scode==233|scode==248|scode==469|scode==534|scode==443
|scode==548|scode==273|scode==694|scode==293|scode==566|scode==456|scode==199|scode==578|scode==186|scode==299);

*******************************************;
**************migration variables**********;
*******************************************;

replace mig1990low_new=low1990 if scode==hcode;
replace mig1990med_new=med1990 if scode==hcode;
replace mig1990high_new=high1990 if scode==hcode;
replace mig2000low_new=low2000 if scode==hcode;
replace mig2000med_new=med2000 if scode==hcode;
replace mig2000high_new=high2000 if scode==hcode;

drop low1990 med1990 high1990 low2000 med2000 high2000 ;

replace mig1990_new=mig1990low_new+mig1990med_new+mig1990high_new if scode==hcode;
replace mig2000_new=mig2000low_new+mig2000med_new+mig2000high_new if scode==hcode;

egen s_low1990_new=max(mig1990low_new),by (scode);
egen s_med1990_new=max(mig1990med_new),by (scode);
egen s_high1990_new=max(mig1990high_new),by (scode);
egen s_low2000_new=max(mig2000low_new),by (scode);
egen s_med2000_new=max(mig2000med_new),by (scode);
egen s_high2000_new=max(mig2000high_new),by (scode);

gen ps_mig1990low_new=100*mig1990low_new/s_low1990_new;
gen ps_mig1990med_new=100*mig1990med_new/s_med1990_new;
gen ps_mig1990high_new=100*mig1990high_new/s_high1990_new;
gen ps_mig2000low_new=100*mig2000low_new/s_low2000_new;
gen ps_mig2000med_new=100*mig2000med_new/s_med2000_new;
gen ps_mig2000high_new=100*mig2000high_new/s_high2000_new;

gen ps_mig1990_new=100*mig1990_new/(s_low1990_new+s_med1990_new+s_high1990_new);
gen ps_mig2000_new=100*mig2000_new/(s_low2000_new+s_med2000_new+s_high2000_new);

gen ls_low1990_new=log(s_low1990_new);
gen ls_med1990_new=log(s_med1990_new);
gen ls_high1990_new=log(s_high1990_new);
gen ls_low2000_new=log(s_low2000_new);
gen ls_med2000_new=log(s_med2000_new);
gen ls_high2000_new=log(s_high2000_new);

gen ps_h_l2000_new=ps_mig2000high_new-ps_mig2000low_new;
gen ps_h_l1990_new=ps_mig1990high_new-ps_mig1990low_new;

gen ps_h_m2000_new=ps_mig2000high_new-ps_mig2000med_new;
gen ps_h_m1990_new=ps_mig1990high_new-ps_mig1990med_new;

gen ps_m_l2000_new=ps_mig2000med_new-ps_mig2000low_new;
gen ps_m_l1990_new=ps_mig1990med_new-ps_mig1990low_new;


*******************************************;
******host country's labor force by skill**;
*******************************************;

gen hdomestic90low= mig1990low_new if scode==hcode;
egen hdomestic90low2=mean(hdomestic90low),by(hcode);
drop hdomestic90low;
rename hdomestic90low2 hdomestic90low;
gen hdomestic00low= mig2000low_new if scode==hcode;
egen hdomestic00low2=mean(hdomestic00low),by(hcode);
drop hdomestic00low;
rename hdomestic00low2 hdomestic00low;

gen hdomestic90med= mig1990med_new if scode==hcode;
egen hdomestic90med2=mean(hdomestic90med),by(hcode);
drop hdomestic90med;
rename hdomestic90med2 hdomestic90med;
gen hdomestic00med= mig2000med_new if scode==hcode;
egen hdomestic00med2=mean(hdomestic00med),by(hcode);
drop hdomestic00med;
rename hdomestic00med2 hdomestic00med;

gen hdomestic90high= mig1990high_new if scode==hcode;
egen hdomestic90high2=mean(hdomestic90high),by(hcode);
drop hdomestic90high;
rename hdomestic90high2 hdomestic90high;
gen hdomestic00high= mig2000high_new if scode==hcode;
egen hdomestic00high2=mean(hdomestic00high),by(hcode);
drop hdomestic00high;
rename hdomestic00high2 hdomestic00high;

gen lhdomestic90low=log(hdomestic90low);
gen lhdomestic00low=log(hdomestic00low);
gen lhdomestic90med=log(hdomestic90med);
gen lhdomestic00med=log(hdomestic00med);
gen lhdomestic90high=log(hdomestic90high);
gen lhdomestic00high=log(hdomestic00high);

**********************************;
**********legal origin dummies****;
**********************************;

gen h_french=(hcode==174|hcode==138|hcode==136|hcode==182|hcode==184|hcode==124|hcode==132|hcode==964);
gen h_scandinavian=(hcode==176|hcode==128|hcode==142|hcode==144|hcode==172);
gen h_english=(hcode==112|hcode==178);
gen h_german=(hcode==146|hcode==122|hcode==134|hcode==944|hcode==935);
gen h_ger_fre=h_french+h_german;

*************************************;
**********BENEFITS*******************;
*************************************;

** the following is 1974-1990 average of benefits (in logs), taken from Razin, Sadka Swagel 2002*****;

gen lh1990_benefit_pc2=.;
replace lh1990_benefit_pc2=7.356854	   if hcode==112;
replace lh1990_benefit_pc2=7.936669	   if hcode==122;
replace lh1990_benefit_pc2=8.243264	   if hcode==124;
replace lh1990_benefit_pc2=8.183059	   if hcode==128;
replace lh1990_benefit_pc2=8.245379	   if hcode==132;
replace lh1990_benefit_pc2=7.836204	   if hcode==134;
replace lh1990_benefit_pc2=8.118244	   if hcode==136;
replace lh1990_benefit_pc2=8.23401	   if hcode==138;
replace lh1990_benefit_pc2=7.996099    if hcode==142;
replace lh1990_benefit_pc2=8.541639	   if hcode==144;
replace lh1990_benefit_pc2=8.105394	   if hcode==146;
replace lh1990_benefit_pc2=8.096037	   if hcode==172;
replace lh1990_benefit_pc2=7.844798	   if hcode==174;
replace lh1990_benefit_pc2=7.286938696 if hcode==178;
replace lh1990_benefit_pc2=7.719279	   if hcode==182;
replace lh1990_benefit_pc2=7.296605	   if hcode==184;

gen ls1990_benefit_pc2=.;
replace ls1990_benefit_pc2=7.356854	   if scode==112;
replace ls1990_benefit_pc2=7.936669	   if scode==122;
replace ls1990_benefit_pc2=8.243264	   if scode==124;
replace ls1990_benefit_pc2=8.183059	   if scode==128;
replace ls1990_benefit_pc2=8.245379	   if scode==132;
replace ls1990_benefit_pc2=7.836204	   if scode==134;
replace ls1990_benefit_pc2=8.118244	   if scode==136;
replace ls1990_benefit_pc2=8.23401	   if scode==138;
replace ls1990_benefit_pc2=7.996099    if scode==142;
replace ls1990_benefit_pc2=8.541639	   if scode==144;
replace ls1990_benefit_pc2=8.105394	   if scode==146;
replace ls1990_benefit_pc2=8.096037	   if scode==172;
replace ls1990_benefit_pc2=7.844798	   if scode==174;
replace ls1990_benefit_pc2=7.286938696 if scode==178;
replace ls1990_benefit_pc2=7.719279	   if scode==182;
replace ls1990_benefit_pc2=7.296605	   if scode==184;

*** the following is different averages of total social benefits, taken fron OECD.stat;

gen h_benefits80_85=.;
gen h_benefits80_90=.;
gen h_benefits80_95=.;
gen h_benefits80_00=.;
gen h_benefits80_05=.;

replace h_benefits80_85=	4628.95	if hcode==	122	;
replace h_benefits80_85=	4858.033333	if hcode==	124	;
replace h_benefits80_85=	4860.166667	if hcode==	128	;
replace h_benefits80_85=	3584.966667	if hcode==	172	;
replace h_benefits80_85=	4198.066667	if hcode==	132	;
replace h_benefits80_85=	3732.45	if hcode==	134	;
replace h_benefits80_85=	2038.933333	if hcode==	174	;
replace h_benefits80_85=	2097.816667	if hcode==	178	;
replace h_benefits80_85=	3564.2	if hcode==	136	;
replace h_benefits80_85=	5004.116667	if hcode==	138	;
replace h_benefits80_85=	4025.8	if hcode==	142	;
replace h_benefits80_85=	1019.8	if hcode==	182	;
replace h_benefits80_85=	2215.716667	if hcode==	184	;
replace h_benefits80_85=	5635.666667	if hcode==	144	;
replace h_benefits80_85=	3670.516667	if hcode==	146	;
replace h_benefits80_85=	3207.15	if hcode==	112	;
replace h_benefits80_90=	4971.133333	if hcode==	122	;
replace h_benefits80_90=	5121.745455	if hcode==	124	;
replace h_benefits80_90=	5193.136364	if hcode==	128	;
replace h_benefits80_90=	4153.4	if hcode==	172	;
replace h_benefits80_90=	4660.572727	if hcode==	132	;
replace h_benefits80_90=	3952.727273	if hcode==	134	;
replace h_benefits80_90=	2181.427273	if hcode==	174	;
replace h_benefits80_90=	2313.436364	if hcode==	178	;
replace h_benefits80_90=	3902.809091	if hcode==	136	;
replace h_benefits80_90=	5142.763636	if hcode==	138	;
replace h_benefits80_90=	5325.06	if hcode==	142	;
replace h_benefits80_90=	1174.845455	if hcode==	182	;
replace h_benefits80_90=	2478.645455	if hcode==	184	;
replace h_benefits80_90=	6166.054545	if hcode==	144	;
replace h_benefits80_90=	3881.954545	if hcode==	146	;
replace h_benefits80_90=	3422.545455	if hcode==	112	;
replace h_benefits80_95=	5538.55	if hcode==	122	;
replace h_benefits80_95=	5328.2	if hcode==	124	;
replace h_benefits80_95=	5436.207143	if hcode==	128	;
replace h_benefits80_95=	4615.235714	if hcode==	172	;
replace h_benefits80_95=	4914.507143	if hcode==	132	;
replace h_benefits80_95=	4324.978571	if hcode==	134	;
replace h_benefits80_95=	2260.414286	if hcode==	174	;
replace h_benefits80_95=	2384.05	if hcode==	178	;
replace h_benefits80_95=	4056.321429	if hcode==	136	;
replace h_benefits80_95=	5341.478571	if hcode==	138	;
replace h_benefits80_95=	5835.15	if hcode==	142	;
replace h_benefits80_95=	1358.521429	if hcode==	182	;
replace h_benefits80_95=	2748.578571	if hcode==	184	;
replace h_benefits80_95=	6498.864286	if hcode==	144	;
replace h_benefits80_95=	4044.128571	if hcode==	146	;
replace h_benefits80_95=	3569.028571	if hcode==	112	;
replace h_benefits80_00=	5837.95	if hcode==	122	;
replace h_benefits80_00=	5454.35	if hcode==	124	;
replace h_benefits80_00=	5675.95	if hcode==	128	;
replace h_benefits80_00=	4844.8875	if hcode==	172	;
replace h_benefits80_00=	5088.80625	if hcode==	132	;
replace h_benefits80_00=	4553.5125	if hcode==	134	;
replace h_benefits80_00=	2316.48125	if hcode==	174	;
replace h_benefits80_00=	2451.5	if hcode==	178	;
replace h_benefits80_00=	4134.26875	if hcode==	136	;
replace h_benefits80_00=	5415.625	if hcode==	138	;
replace h_benefits80_00=	6105.15	if hcode==	142	;
replace h_benefits80_00=	1478.325	if hcode==	182	;
replace h_benefits80_00=	2882.2625	if hcode==	184	;
replace h_benefits80_00=	6654.23125	if hcode==	144	;
replace h_benefits80_00=	4170.1	if hcode==	146	;
replace h_benefits80_00=	3685.50625	if hcode==	112	;
replace h_benefits80_05=	6888.288889	if hcode==	122	;
replace h_benefits80_05=	6089.146154	if hcode==	124	;
replace h_benefits80_05=	6470.65	if hcode==	128	;
replace h_benefits80_05=	5536.607692	if hcode==	172	;
replace h_benefits80_05=	5875.742308	if hcode==	132	;
replace h_benefits80_05=	5419.707692	if hcode==	134	;
replace h_benefits80_05=	2844.884615	if hcode==	174	;
replace h_benefits80_05=	3133.023077	if hcode==	178	;
replace h_benefits80_05=	4830.873077	if hcode==	136	;
replace h_benefits80_05=	5636.057692	if hcode==	138	;
replace h_benefits80_05=	7250.4	if hcode==	142	;
replace h_benefits80_05=	2125.02	if hcode==	182	;
replace h_benefits80_05=	3474.369231	if hcode==	184	;
replace h_benefits80_05=	7276.957692	if hcode==	144	;
replace h_benefits80_05=	4843.557692	if hcode==	146	;
replace h_benefits80_05=	4251.030769	if hcode==	112	;


gen lh_benefits80_85=log(h_benefits80_85);
gen lh_benefits80_90=log(h_benefits80_90);
gen lh_benefits80_95=log(h_benefits80_95);
gen lh_benefits80_00=log(h_benefits80_00);
gen lh_benefits80_05=log(h_benefits80_05);





gen s_benefits80_90=.;
replace s_benefits80_90=	4971.133333	if scode==	122	;
replace s_benefits80_90=	5121.745455	if scode==	124	;
replace s_benefits80_90=	5193.136364	if scode==	128	;
replace s_benefits80_90=	4153.4	if scode==	172	;
replace s_benefits80_90=	4660.572727	if scode==	132	;
replace s_benefits80_90=	3952.727273	if scode==	134	;
replace s_benefits80_90=	2181.427273	if scode==	174	;
replace s_benefits80_90=	2313.436364	if scode==	178	;
replace s_benefits80_90=	3902.809091	if scode==	136	;
replace s_benefits80_90=	5142.763636	if scode==	138	;
replace s_benefits80_90=	5325.06	if scode==	142	;
replace s_benefits80_90=	1174.845455	if scode==	182	;
replace s_benefits80_90=	2478.645455	if scode==	184	;
replace s_benefits80_90=	6166.054545	if scode==	144	;
replace s_benefits80_90=	3881.954545	if scode==	146	;
replace s_benefits80_90=	3422.545455	if scode==	112	;

gen ls_benefits80_90=log(s_benefits80_90);

********************************;
**** adding common language*****;
********************************;

sort scode hcode;
merge scode hcode using C:\Alon\CR_migration\mig_fdi102004.dta,keep(d_language);
rename d_language comlang;
drop _mer;
aorder ;
order scode hcode;


collapse comlang- s_med2000_new,by(scode hcode);

*******************************************;
************adding variables from DD file**;
*******************************************;


merge scode hcode using C:\Alon\CR_migration\DD.dta,keep(distance s_defence s_gini1990 s1990_iq1 s1990_iq2 s1990_iq3 
s1990_iq4 s1990_iq5 s1990_itax s2000_itax s1990_igovjobs s1990_unemp s1990_unemp2 s1990_open s1990_rgdpch s_rgdpwok1990
h_defence h_gini1990 h1990_iq1 h1990_iq2 h1990_iq3 h1990_iq4 
h1990_iq5 h1990_itax h2000_itax h1990_igovjobs h1990_unemp h1990_unemp2 h1990_open h1990_rgdpch h_rgdpwok1990) sort ;
drop _me;


*******************************************;
****************GDP************************;
*******************************************;

replace s1990_rgdpch=18050.22353 if scode==193;
replace h1990_rgdpch=18050.22353 if hcode==193;
replace s_rgdpwok1990=38486.66706 if scode==193;
replace h_rgdpwok1990=38486.66706 if hcode==193;

replace s1990_rgdpch=19141.70941 if scode==156;
replace h1990_rgdpch=19141.70941 if hcode==156;
replace s_rgdpwok1990=38582.54353 if scode==156;
replace h_rgdpwok1990=38582.54353 if hcode==156;

replace s1990_rgdpch=14793.08412 if scode==532;
replace h1990_rgdpch=14793.08412 if hcode==532;
replace s_rgdpwok1990=30025.25471 if scode==532;
replace h_rgdpwok1990=30025.25471 if hcode==532;

replace s1990_rgdpch=14759.52471 if scode==436;
replace h1990_rgdpch=14759.52471 if hcode==436;
replace s_rgdpwok1990=38836.77941 if scode==436;
replace h_rgdpwok1990=38836.77941 if hcode==436;

replace s1990_rgdpch=16449.31294 if scode==158;
replace h1990_rgdpch=16449.31294 if hcode==158;
replace s_rgdpwok1990=32710.49941 if scode==158;
replace h_rgdpwok1990=32710.49941 if hcode==158;

replace s1990_rgdpch=5617.153529 if scode==542;
replace h1990_rgdpch=5617.153529 if hcode==542;
replace s_rgdpwok1990=13247.14824 if scode==542;
replace h_rgdpwok1990=13247.14824 if hcode==542;

replace s1990_rgdpch=16513.11471 if scode==196;
replace h1990_rgdpch=16513.11471 if hcode==196;
replace s_rgdpwok1990=37653.78647 if scode==196;
replace h_rgdpwok1990=37653.78647 if hcode==196;

replace s1990_rgdpch=13571.43529 if scode==576;
replace h1990_rgdpch=13571.43529 if hcode==576;
replace s_rgdpwok1990=28902.84588 if scode==576;
replace h_rgdpwok1990=28902.84588 if hcode==576;

replace s1990_rgdpch=6950.715294 if scode==528;
replace h1990_rgdpch=6950.715294 if hcode==528;
replace s_rgdpwok1990=16479.06941 if scode==528;
replace h_rgdpwok1990=16479.06941 if hcode==528;

replace s1990_rgdpch=22833.62059 if scode==111;
replace h1990_rgdpch=22833.62059 if hcode==111;
replace s_rgdpwok1990=47107.11353 if scode==111;
replace h_rgdpwok1990=47107.11353 if hcode==111;

replace	h1990_rgdpch	=	16445.17	if	hcode==	112	;
replace	h1990_rgdpch	=	18346.32	if	hcode==	122	;
replace	h1990_rgdpch	=	17187.82	if	hcode==	124	;
replace	h1990_rgdpch	=	19777.21	if	hcode==	128	;
replace	h1990_rgdpch	=	17963.47	if	hcode==	132	;
replace	h1990_rgdpch	=	17750.04	if	hcode==	134	;
replace	h1990_rgdpch	=	16115.24	if	hcode==	136	;
replace	h1990_rgdpch	=	18208.66	if	hcode==	138	;
replace	h1990_rgdpch	=	20287.51	if	hcode==	142	;
replace	h1990_rgdpch	=	18868.21	if	hcode==	144	;
replace	h1990_rgdpch	=	23929.13	if	hcode==	146	;
replace	h1990_rgdpch	=	16554.72	if	hcode==	172	;
replace	h1990_rgdpch	=	11365.07	if	hcode==	174	;
replace	h1990_rgdpch	=	10673.38	if	hcode==	178	;
replace	h1990_rgdpch	=	10294.84	if	hcode==	182	;
replace	h1990_rgdpch	=	12644.17	if	hcode==	184	;
replace	h_rgdpwok1990	=	34064.8	if	hcode==	112	;
replace	h_rgdpwok1990	=	40769.47	if	hcode==	122	;
replace	h_rgdpwok1990	=	43066.78	if	hcode==	124	;
replace	h_rgdpwok1990	=	36837.67	if	hcode==	128	;
replace	h_rgdpwok1990	=	41006.29	if	hcode==	132	;
replace	h_rgdpwok1990	=	36678.18	if	hcode==	134	;
replace	h_rgdpwok1990	=	39325.41	if	hcode==	136	;
replace	h_rgdpwok1990	=	43844.77	if	hcode==	138	;
replace	h_rgdpwok1990	=	42437.7	if	hcode==	142	;
replace	h_rgdpwok1990	=	36768.37	if	hcode==	144	;
replace	h_rgdpwok1990	=	48088.52	if	hcode==	146	;
replace	h_rgdpwok1990	=	32747.89	if	hcode==	172	;
replace	h_rgdpwok1990	=	28610.29	if	hcode==	174	;
replace	h_rgdpwok1990	=	28647.35	if	hcode==	178	;
replace	h_rgdpwok1990	=	21987.13	if	hcode==	182	;
replace	h_rgdpwok1990	=	32842.23	if	hcode==	184	;

*******************************;
*****adding country names******;
*******************************;

gen source=".";
replace source =	"	US	"	if scode ==	111	;
replace source =	"	UK	"	if scode ==	112	;
replace source =	"	Austria	"	if scode ==	122	;
replace source =	"	Belgium	"	if scode ==	124	;
replace source =	"	Denmark	"	if scode ==	128	;
replace source =	"	France	"	if scode ==	132	;
replace source =	"	Germany	"	if scode ==	134	;
replace source =	"	Italy	"	if scode ==	136	;
replace source =	"	Netherlands	"	if scode ==	138	;
replace source =	"	Norway	"	if scode ==	142	;
replace source =	"	Sweden	"	if scode ==	144	;
replace source =	"	Switzerland	"	if scode ==	146	;
replace source =	"	Canada	"	if scode ==	156	;
replace source =	"	Japan	"	if scode ==	158	;
replace source =	"	Finland	"	if scode ==	172	;
replace source =	"	Greece	"	if scode ==	174	;
replace source =	"	Ireland	"	if scode ==	178	;
replace source =	"	Portugal	"	if scode ==	182	;
replace source =	"	Spain	"	if scode ==	184	;
replace source =	"	Australia	"	if scode ==	193	;
replace source =	"	New Zealand	"	if scode ==	196	;
replace source =	"	Israel	"	if scode ==	436	;
replace source =	"	Taiwan	"	if scode ==	528	;
replace source =	"	Hong Kong	"	if scode ==	532	;
replace source =	"	Korea	"	if scode ==	542	;
replace source =	"	Singapore	"	if scode ==	576	;


gen host=".";
replace host =	"	US	"	if hcode ==	111	;
replace host =	"	UK	"	if hcode ==	112	;
replace host =	"	Austria	"	if hcode ==	122	;
replace host =	"	Belgium	"	if hcode ==	124	;
replace host =	"	Denmark	"	if hcode ==	128	;
replace host =	"	France	"	if hcode ==	132	;
replace host =	"	Germany	"	if hcode ==	134	;
replace host =	"	Italy	"	if hcode ==	136	;
replace host =	"	Netherlands	"	if hcode ==	138	;
replace host =	"	Norway	"	if hcode ==	142	;
replace host =	"	Sweden	"	if hcode ==	144	;
replace host =	"	Switzerland	"	if hcode ==	146	;
replace host =	"	Canada	"	if hcode ==	156	;
replace host =	"	Japan	"	if hcode ==	158	;
replace host =	"	Finland	"	if hcode ==	172	;
replace host =	"	Greece	"	if hcode ==	174	;
replace host =	"	Ireland	"	if hcode ==	178	;
replace host =	"	Portugal	"	if hcode ==	182	;
replace host =	"	Spain	"	if hcode ==	184	;
replace host =	"	Australia	"	if hcode ==	193	;
replace host =	"	New Zealand	"	if hcode ==	196	;
replace host =	"	Israel	"	if hcode ==	436	;
replace host =	"	Taiwan	"	if hcode ==	528	;
replace host =	"	Hong Kong	"	if hcode ==	532	;
replace host =	"	Korea	"	if hcode ==	542	;
replace host =	"	Singapore	"	if hcode ==	576	;

*****************************************************************************************;
************expanding distance data******************************************************;
** the following is great-circle calulation based on latitudes from http://www.convertunits.com/distance/;


replace distance=	4348	if scode==	111	& hcode==	112	;
replace distance=	5161	if scode==	111	& hcode==	122	;
replace distance=	4677	if scode==	111	& hcode==	124	;
replace distance=	4681	if scode==	111	& hcode==	128	;
replace distance=	4784	if scode==	111	& hcode==	132	;
replace distance=	4850	if scode==	111	& hcode==	134	;
replace distance=	5343	if scode==	111	& hcode==	136	;
replace distance=	4676	if scode==	111	& hcode==	138	;
replace distance=	4446	if scode==	111	& hcode==	142	;
replace distance=	4580	if scode==	111	& hcode==	144	;
replace distance=	4978	if scode==	111	& hcode==	146	;
replace distance=	4751	if scode==	111	& hcode==	172	;
replace distance=	5873	if scode==	111	& hcode==	174	;
replace distance=	4156	if scode==	111	& hcode==	178	;
replace distance=	4591	if scode==	111	& hcode==	182	;
replace distance=	4754	if scode==	111	& hcode==	184	;
replace distance=	3241	if scode==	156	& hcode==	112	;
replace distance=	4019	if scode==	156	& hcode==	122	;
replace distance=	3572	if scode==	156	& hcode==	124	;
replace distance=	3452	if scode==	156	& hcode==	128	;
replace distance=	3777	if scode==	156	& hcode==	132	;
replace distance=	3698	if scode==	156	& hcode==	134	;
replace distance=	4265	if scode==	156	& hcode==	136	;
replace distance=	3531	if scode==	156	& hcode==	138	;
replace distance=	3139	if scode==	156	& hcode==	142	;
replace distance=	3246	if scode==	156	& hcode==	144	;
replace distance=	3893	if scode==	156	& hcode==	146	;
replace distance=	3348	if scode==	156	& hcode==	172	;
replace distance=	4737	if scode==	156	& hcode==	174	;
replace distance=	3118	if scode==	156	& hcode==	178	;
replace distance=	3822	if scode==	156	& hcode==	182	;
replace distance=	3924	if scode==	156	& hcode==	184	;
replace distance=	5792	if scode==	158	& hcode==	112	;
replace distance=	5755	if scode==	158	& hcode==	122	;
replace distance=	5833	if scode==	158	& hcode==	124	;
replace distance=	5399	if scode==	158	& hcode==	128	;
replace distance=	6160	if scode==	158	& hcode==	132	;
replace distance=	5691	if scode==	158	& hcode==	134	;
replace distance=	6003	if scode==	158	& hcode==	136	;
replace distance=	5696	if scode==	158	& hcode==	138	;
replace distance=	5087	if scode==	158	& hcode==	142	;
replace distance=	4974	if scode==	158	& hcode==	144	;
replace distance=	5935	if scode==	158	& hcode==	146	;
replace distance=	4620	if scode==	158	& hcode==	172	;
replace distance=	5858	if scode==	158	& hcode==	174	;
replace distance=	5973	if scode==	158	& hcode==	178	;
replace distance=	6804	if scode==	158	& hcode==	182	;
replace distance=	6672	if scode==	158	& hcode==	184	;
replace distance=	9499	if scode==	193	& hcode==	112	;
replace distance=	8927	if scode==	193	& hcode==	122	;
replace distance=	9319	if scode==	193	& hcode==	124	;
replace distance=	9003	if scode==	193	& hcode==	128	;
replace distance=	9472	if scode==	193	& hcode==	132	;
replace distance=	9102	if scode==	193	& hcode==	134	;
replace distance=	8950	if scode==	193	& hcode==	136	;
replace distance=	9221	if scode==	193	& hcode==	138	;
replace distance=	8903	if scode==	193	& hcode==	142	;
replace distance=	8745	if scode==	193	& hcode==	144	;
replace distance=	9179	if scode==	193	& hcode==	146	;
replace distance=	8385	if scode==	193	& hcode==	172	;
replace distance=	8446	if scode==	193	& hcode==	174	;
replace distance=	9753	if scode==	193	& hcode==	178	;
replace distance=	10047	if scode==	193	& hcode==	182	;
replace distance=	9832	if scode==	193	& hcode==	184	;
replace distance=	11513	if scode==	196	& hcode==	112	;
replace distance=	11387	if scode==	196	& hcode==	122	;
replace distance=	11602	if scode==	196	& hcode==	124	;
replace distance=	11169	if scode==	196	& hcode==	128	;
replace distance=	11907	if scode==	196	& hcode==	132	;
replace distance=	11439	if scode==	196	& hcode==	134	;
replace distance=	11464	if scode==	196	& hcode==	136	;
replace distance=	11465	if scode==	196	& hcode==	138	;
replace distance=	10834	if scode==	196	& hcode==	142	;
replace distance=	10738	if scode==	196	& hcode==	144	;
replace distance=	11628	if scode==	196	& hcode==	146	;
replace distance=	10390	if scode==	196	& hcode==	172	;
replace distance=	10956	if scode==	196	& hcode==	174	;
replace distance=	11596	if scode==	196	& hcode==	178	;
replace distance=	12288	if scode==	196	& hcode==	182	;
replace distance=	12312	if scode==	196	& hcode==	184	;
replace distance=	2385	if scode==	436	& hcode==	112	;
replace distance=	1573	if scode==	436	& hcode==	122	;
replace distance=	2060	if scode==	436	& hcode==	124	;
replace distance=	2072	if scode==	436	& hcode==	128	;
replace distance=	2012	if scode==	436	& hcode==	132	;
replace distance=	1881	if scode==	436	& hcode==	134	;
replace distance=	1433	if scode==	436	& hcode==	136	;
replace distance=	2055	if scode==	436	& hcode==	138	;
replace distance=	2380	if scode==	436	& hcode==	142	;
replace distance=	2285	if scode==	436	& hcode==	144	;
replace distance=	1775	if scode==	436	& hcode==	146	;
replace distance=	2277	if scode==	436	& hcode==	172	;
replace distance=	886	if scode==	436	& hcode==	174	;
replace distance=	2590	if scode==	436	& hcode==	178	;
replace distance=	2448	if scode==	436	& hcode==	182	;
replace distance=	2236	if scode==	436	& hcode==	184	;
replace distance=	6115	if scode==	528	& hcode==	112	;
replace distance=	5814	if scode==	528	& hcode==	122	;
replace distance=	6046	if scode==	528	& hcode==	124	;
replace distance=	5645	if scode==	528	& hcode==	128	;
replace distance=	6317	if scode==	528	& hcode==	132	;
replace distance=	5858	if scode==	528	& hcode==	134	;
replace distance=	5986	if scode==	528	& hcode==	136	;
replace distance=	5919	if scode==	528	& hcode==	138	;
replace distance=	5439	if scode==	528	& hcode==	142	;
replace distance=	5294	if scode==	528	& hcode==	144	;
replace distance=	6042	if scode==	528	& hcode==	146	;
replace distance=	4922	if scode==	528	& hcode==	172	;
replace distance=	5675	if scode==	528	& hcode==	174	;
replace distance=	6344	if scode==	528	& hcode==	178	;
replace distance=	6994	if scode==	528	& hcode==	182	;
replace distance=	6813	if scode==	528	& hcode==	184	;
replace distance=	5965	if scode==	532	& hcode==	112	;
replace distance=	5590	if scode==	532	& hcode==	122	;
replace distance=	5864	if scode==	532	& hcode==	124	;
replace distance=	5482	if scode==	532	& hcode==	128	;
replace distance=	6111	if scode==	532	& hcode==	132	;
replace distance=	5664	if scode==	532	& hcode==	134	;
replace distance=	5736	if scode==	532	& hcode==	136	;
replace distance=	5742	if scode==	532	& hcode==	138	;
replace distance=	5316	if scode==	532	& hcode==	142	;
replace distance=	5164	if scode==	532	& hcode==	144	;
replace distance=	5827	if scode==	532	& hcode==	146	;
replace distance=	4795	if scode==	532	& hcode==	172	;
replace distance=	5386	if scode==	532	& hcode==	174	;
replace distance=	6206	if scode==	532	& hcode==	178	;
replace distance=	6784	if scode==	532	& hcode==	182	;
replace distance=	6592	if scode==	532	& hcode==	184	;
replace distance=	5483	if scode==	542	& hcode==	112	;
replace distance=	5350	if scode==	542	& hcode==	122	;
replace distance=	5483	if scode==	542	& hcode==	124	;
replace distance=	5055	if scode==	542	& hcode==	128	;
replace distance=	5793	if scode==	542	& hcode==	132	;
replace distance=	5322	if scode==	542	& hcode==	134	;
replace distance=	5577	if scode==	542	& hcode==	136	;
replace distance=	5347	if scode==	542	& hcode==	138	;
replace distance=	4780	if scode==	542	& hcode==	142	;
replace distance=	4653	if scode==	542	& hcode==	144	;
replace distance=	5548	if scode==	542	& hcode==	146	;
replace distance=	4287	if scode==	542	& hcode==	172	;
replace distance=	5382	if scode==	542	& hcode==	174	;
replace distance=	5686	if scode==	542	& hcode==	178	;
replace distance=	6458	if scode==	542	& hcode==	182	;
replace distance=	6306	if scode==	542	& hcode==	184	;
replace distance=	6780	if scode==	576	& hcode==	112	;
replace distance=	6173	if scode==	576	& hcode==	122	;
replace distance=	6574	if scode==	576	& hcode==	124	;
replace distance=	6288	if scode==	576	& hcode==	128	;
replace distance=	6718	if scode==	576	& hcode==	132	;
replace distance=	6355	if scode==	576	& hcode==	134	;
replace distance=	6206	if scode==	576	& hcode==	136	;
replace distance=	6483	if scode==	576	& hcode==	138	;
replace distance=	6258	if scode==	576	& hcode==	142	;
replace distance=	6095	if scode==	576	& hcode==	144	;
replace distance=	6425	if scode==	576	& hcode==	146	;
replace distance=	5764	if scode==	576	& hcode==	172	;
replace distance=	5721	if scode==	576	& hcode==	174	;
replace distance=	7037	if scode==	576	& hcode==	178	;
replace distance=	7312	if scode==	576	& hcode==	182	;
replace distance=	7097	if scode==	576	& hcode==	184	;


*****************************************************************;
****generating 2 groups: free and policy controlled migration****;
******************************************************************;

gen Free=( scode==122 |  scode==124 |  scode==128 |  scode==172 |  scode==132 | 
 scode==134 |  scode==174 |  scode==178 | scode==136 |  scode==138 | 
 scode==142 |  scode==182 |  scode==184 |  scode==144 |  scode==146 | 
 scode==112 );

gen restrict=1-Free;

drop if developing==1;
drop if (source=="." | host==".");
drop developing;





**********************************;
**** robustness variables**********;
***********************************;

gen eu95=(scode==122|scode==144|scode==172|hcode==122|hcode==144|hcode==172);
gen eu95a=(eu95|scode==142|scode==146|hcode==142|hcode==146);


/* the following are additional data on Greece's defense expenses which became available, and minor correction
on the same data for Austria, due to the updataed data from oecd.stat on August 2008*/

replace  h_defence=0.989902606 if hcode==122;
replace  s_defence=0.989902606 if scode==122;
replace  h_defence=2.495455262 if hcode==174;
replace  s_defence=2.495455262 if scode==174;

/*** the following data relates to switzerlands defense measure as a percentage of its GDP - average of 1989-1990-1991
taken from a paper by Thomas Bernauer, Vally Koubi and Fabio Ernst " National and Regional Economic Consequenses
od Swiss Defense spending"***/

replace h_defence=1.5974 if hcode==146;

gen lben_h=log(h_rgdpwok1990*(h1990_itax- h_defence));

gen lben_s=log(s_rgdpwok1990*(s1990_itax- s_defence));
sort scode hcode;



replace h1990_itax=	26.519529	if hcode==	112	;
replace h1990_itax=	38.216235	if hcode==	122	;
replace h1990_itax=	44.240529	if hcode==	124	;
replace h1990_itax=	42.1486	if hcode==	128	;
replace h1990_itax=	41.144295	if hcode==	132	;
replace h1990_itax=	39.054118	if hcode==	134	;
replace h1990_itax=	36.078059	if hcode==	136	;
replace h1990_itax=	49.312059	if hcode==	138	;
replace h1990_itax=	38.91625	if hcode==	142	;
replace h1990_itax=	48.065765	if hcode==	144	;
replace h1990_itax=	31.701706	if hcode==	146	;
replace h1990_itax=	31.710765	if hcode==	172	;
replace h1990_itax=	30.148333	if hcode==	174	;
replace h1990_itax=	39.300833	if hcode==	178	;
replace h1990_itax=	32.477084	if hcode==	182	;
replace h1990_itax=	30.714735	if hcode==	184	;

replace lben_h=	13.58157	if hcode==	112	;
replace lben_h=	14.23271	if hcode==	122	;
replace lben_h=	14.42516	if hcode==	124	;
replace lben_h=	14.21144	if hcode==	128	;
replace lben_h=	14.27983	if hcode==	132	;
replace lben_h=	14.13778	if hcode==	134	;
replace lben_h=	14.13005	if hcode==	136	;
replace lben_h=	14.55084	if hcode==	138	;
replace lben_h=	14.24775	if hcode==	142	;
replace lben_h=	14.3328	if hcode==	144	;
replace lben_h=   14.185467		if hcode==	146	;
replace lben_h=	13.79207	if hcode==	172	;
replace lben_h=	13.58125	if hcode==	174	;
replace lben_h=	13.90865	if hcode==	178	;
replace lben_h=	13.43043	if hcode==	182	;
replace lben_h=	13.78714	if hcode==	184	;

replace h1990_iq1=	8.5739193	if hcode==	112	;
replace h1990_iq1=	7.0788229	if hcode==	122	;
replace h1990_iq1=	8.3339583	if hcode==	124	;
replace h1990_iq1=	8.0009825	if hcode==	128	;
replace h1990_iq1=	6.6175583	if hcode==	132	;
replace h1990_iq1=	8.8045564	if hcode==	134	;
replace h1990_iq1=	9.4294117	if hcode==	136	;
replace h1990_iq1=	7.8884416	if hcode==	138	;
replace h1990_iq1=	6.3079035	if hcode==	142	;
replace h1990_iq1=	6.8434375	if hcode==	144	;
replace h1990_iq1=	6.3084616	if hcode==	146	;
replace h1990_iq1=	10.504366	if hcode==	172	;
replace h1990_iq1=	6.7800495	if hcode==	174	;
replace h1990_iq1=	6.5573192	if hcode==	178	;
replace h1990_iq1=	8.6241616	if hcode==	182	;
replace h1990_iq1=	7.8790001	if hcode==	184	;

replace s1990_iq1=	8.5739193	if scode==	112	;
replace s1990_iq1=	7.0788229	if scode==	122	;
replace s1990_iq1=	8.3339583	if scode==	124	;
replace s1990_iq1=	8.0009825	if scode==	128	;
replace s1990_iq1=	6.6175583	if scode==	132	;
replace s1990_iq1=	8.8045564	if scode==	134	;
replace s1990_iq1=	9.4294117	if scode==	136	;
replace s1990_iq1=	7.8884416	if scode==	138	;
replace s1990_iq1=	6.3079035	if scode==	142	;
replace s1990_iq1=	6.8434375	if scode==	144	;
replace s1990_iq1=	6.3084616	if scode==	146	;
replace s1990_iq1=	10.504366	if scode==	172	;
replace s1990_iq1=	6.7800495	if scode==	174	;
replace s1990_iq1=	6.5573192	if scode==	178	;
replace s1990_iq1=	8.6241616	if scode==	182	;
replace s1990_iq1=	7.8790001	if scode==	184	;

replace s1990_iq2=	13.265116	if scode==	112	;
replace s1990_iq2=	13.738842	if scode==	122	;
replace s1990_iq2=	14.103333	if scode==	124	;
replace s1990_iq2=	13.616984	if scode==	128	;
replace s1990_iq2=	12.242558	if scode==	132	;
replace s1990_iq2=	13.47358	if scode==	134	;
replace s1990_iq2=	13.145882	if scode==	136	;
replace s1990_iq2=	13.338316	if scode==	138	;
replace s1990_iq2=	12.200541	if scode==	142	;
replace s1990_iq2=	12.617187	if scode==	144	;
replace s1990_iq2=	11.549231	if scode==	146	;
replace s1990_iq2=	15.049386	if scode==	172	;
replace s1990_iq2=	12.779056	if scode==	174	;
replace s1990_iq2=	12.124202	if scode==	178	;
replace s1990_iq2=	14.164406	if scode==	182	;
replace s1990_iq2=	13.176667	if scode==	184	;

replace h1990_iq2=	13.265116	if hcode==	112	;
replace h1990_iq2=	13.738842	if hcode==	122	;
replace h1990_iq2=	14.103333	if hcode==	124	;
replace h1990_iq2=	13.616984	if hcode==	128	;
replace h1990_iq2=	12.242558	if hcode==	132	;
replace h1990_iq2=	13.47358	if hcode==	134	;
replace h1990_iq2=	13.145882	if hcode==	136	;
replace h1990_iq2=	13.338316	if hcode==	138	;
replace h1990_iq2=	12.200541	if hcode==	142	;
replace h1990_iq2=	12.617187	if hcode==	144	;
replace h1990_iq2=	11.549231	if hcode==	146	;
replace h1990_iq2=	15.049386	if hcode==	172	;
replace h1990_iq2=	12.779056	if hcode==	174	;
replace h1990_iq2=	12.124202	if hcode==	178	;
replace h1990_iq2=	14.164406	if hcode==	182	;
replace h1990_iq2=	13.176667	if hcode==	184	;

replace h1990_iq3=	17.690715	if hcode==	112	;
replace h1990_iq3=	18.465004	if hcode==	122	;
replace h1990_iq3=	18.665208	if hcode==	124	;
replace h1990_iq3=	17.571132	if hcode==	128	;
replace h1990_iq3=	17.573665	if hcode==	132	;
replace h1990_iq3=	17.480052	if hcode==	134	;
replace h1990_iq3=	16.502941	if hcode==	136	;
replace h1990_iq3=	17.210345	if hcode==	138	;
replace h1990_iq3=	17.342669	if hcode==	142	;
replace h1990_iq3=	17.675938	if hcode==	144	;
replace h1990_iq3=	16.470769	if hcode==	146	;
replace h1990_iq3=	18.442484	if hcode==	172	;
replace h1990_iq3=	18.638973	if hcode==	174	;
replace h1990_iq3=	16.974338	if hcode==	178	;
replace h1990_iq3=	18.213392	if hcode==	182	;
replace h1990_iq3=	18.460667	if hcode==	184	;

replace s1990_iq3=	17.690715	if scode==	112	;
replace s1990_iq3=	18.465004	if scode==	122	;
replace s1990_iq3=	18.665208	if scode==	124	;
replace s1990_iq3=	17.571132	if scode==	128	;
replace s1990_iq3=	17.573665	if scode==	132	;
replace s1990_iq3=	17.480052	if scode==	134	;
replace s1990_iq3=	16.502941	if scode==	136	;
replace s1990_iq3=	17.210345	if scode==	138	;
replace s1990_iq3=	17.342669	if scode==	142	;
replace s1990_iq3=	17.675938	if scode==	144	;
replace s1990_iq3=	16.470769	if scode==	146	;
replace s1990_iq3=	18.442484	if scode==	172	;
replace s1990_iq3=	18.638973	if scode==	174	;
replace s1990_iq3=	16.974338	if scode==	178	;
replace s1990_iq3=	18.213392	if scode==	182	;
replace s1990_iq3=	18.460667	if scode==	184	;

replace s1990_iq4=	23.141329	if scode==	112	;
replace s1990_iq4=	23.745151	if scode==	122	;
replace s1990_iq4=	23.650625	if scode==	124	;
replace s1990_iq4=	22.511906	if scode==	128	;
replace s1990_iq4=	23.618883	if scode==	132	;
replace s1990_iq4=	22.761374	if scode==	134	;
replace s1990_iq4=	22.842941	if scode==	136	;
replace s1990_iq4=	22.817677	if scode==	138	;
replace s1990_iq4=	23.718591	if scode==	142	;
replace s1990_iq4=	24.492812	if scode==	144	;
replace s1990_iq4=	22.986922	if scode==	146	;
replace s1990_iq4=	22.621485	if scode==	172	;
replace s1990_iq4=	25.0762	if scode==	174	;
replace s1990_iq4=	23.37527	if scode==	178	;
replace s1990_iq4=	22.925728	if scode==	182	;
replace s1990_iq4=	23.581	if scode==	184	;

replace h1990_iq4=	23.141329	if hcode==	112	;
replace h1990_iq4=	23.745151	if hcode==	122	;
replace h1990_iq4=	23.650625	if hcode==	124	;
replace h1990_iq4=	22.511906	if hcode==	128	;
replace h1990_iq4=	23.618883	if hcode==	132	;
replace h1990_iq4=	22.761374	if hcode==	134	;
replace h1990_iq4=	22.842941	if hcode==	136	;
replace h1990_iq4=	22.817677	if hcode==	138	;
replace h1990_iq4=	23.718591	if hcode==	142	;
replace h1990_iq4=	24.492812	if hcode==	144	;
replace h1990_iq4=	22.986922	if hcode==	146	;
replace h1990_iq4=	22.621485	if hcode==	172	;
replace h1990_iq4=	25.0762	if hcode==	174	;
replace h1990_iq4=	23.37527	if hcode==	178	;
replace h1990_iq4=	22.925728	if hcode==	182	;
replace h1990_iq4=	23.581	if hcode==	184	;

replace h1990_iq5=	37.329416	if hcode==	112	;
replace h1990_iq5=	36.965874	if hcode==	122	;
replace h1990_iq5=	35.246875	if hcode==	124	;
replace h1990_iq5=	38.300507	if hcode==	128	;
replace h1990_iq5=	39.947336	if hcode==	132	;
replace h1990_iq5=	37.468881	if hcode==	134	;
replace h1990_iq5=	38.078823	if hcode==	136	;
replace h1990_iq5=	38.778674	if hcode==	138	;
replace h1990_iq5=	40.357806	if hcode==	142	;
replace h1990_iq5=	38.370625	if hcode==	144	;
replace h1990_iq5=	42.684617	if hcode==	146	;
replace h1990_iq5=	33.36392	if hcode==	172	;
replace h1990_iq5=	36.798647	if hcode==	174	;
replace h1990_iq5=	40.966683	if hcode==	178	;
replace h1990_iq5=	36.104354	if hcode==	182	;
replace h1990_iq5=	36.902666	if hcode==	184	;

replace s1990_iq5=	37.329416	if scode==	112	;
replace s1990_iq5=	36.965874	if scode==	122	;
replace s1990_iq5=	35.246875	if scode==	124	;
replace s1990_iq5=	38.300507	if scode==	128	;
replace s1990_iq5=	39.947336	if scode==	132	;
replace s1990_iq5=	37.468881	if scode==	134	;
replace s1990_iq5=	38.078823	if scode==	136	;
replace s1990_iq5=	38.778674	if scode==	138	;
replace s1990_iq5=	40.357806	if scode==	142	;
replace s1990_iq5=	38.370625	if scode==	144	;
replace s1990_iq5=	42.684617	if scode==	146	;
replace s1990_iq5=	33.36392	if scode==	172	;
replace s1990_iq5=	36.798647	if scode==	174	;
replace s1990_iq5=	40.966683	if scode==	178	;
replace s1990_iq5=	36.104354	if scode==	182	;
replace s1990_iq5=	36.902666	if scode==	184	;


***the following serves as an IV measure, based on  h_benefits80_90;
gen hben_regional=.				;
replace hben_regional=	2313.436	if hcode==	112	;
replace hben_regional=	3917.341	if hcode==	122	;
replace hben_regional=	3971.89325	if hcode==	124	;
replace hben_regional=	5214.838333	if hcode==	128	;
replace hben_regional=	4087.1865	if hcode==	132	;
replace hben_regional=	4426.544	if hcode==	134	;
replace hben_regional=	4276.6275	if hcode==	136	;
replace hben_regional=	3966.63875	if hcode==	138	;
replace hben_regional=	5170.863667	if hcode==	142	;
replace hben_regional=	4890.532	if hcode==	144	;
replace hben_regional=	4461.93	if hcode==	146	;
replace hben_regional=	5561.417	if hcode==	172	;
replace hben_regional=	4706.973	if hcode==	174	;
replace hben_regional=	3422.545	if hcode==	178	;
replace hben_regional=	2478.646	if hcode==	182	;
replace hben_regional=	1174.845	if hcode==	184	;
gen lhben_regional=log(hben_regional)				;
gen res_lhben_regional=restrict*lhben_regional;

****the following is based on lh1990_benefit_pc2;
gen regional_lh1990_benefit_pc2=.				;
replace regional_lh1990_benefit_pc2=	1461.091444	if hcode==	112	;
replace regional_lh1990_benefit_pc2=	2921.433472	if hcode==	122	;
replace regional_lh1990_benefit_pc2=	3371.108493	if hcode==	124	;
replace regional_lh1990_benefit_pc2=	3791.508381	if hcode==	128	;
replace regional_lh1990_benefit_pc2=	3369.096095	if hcode==	132	;
replace regional_lh1990_benefit_pc2=	3055.155598	if hcode==	134	;
replace regional_lh1990_benefit_pc2=	3482.809894	if hcode==	136	;
replace regional_lh1990_benefit_pc2=	3379.863684	if hcode==	138	;
replace regional_lh1990_benefit_pc2=	3994.987241	if hcode==	142	;
replace regional_lh1990_benefit_pc2=	3276.859453	if hcode==	144	;
replace regional_lh1990_benefit_pc2=	2664.302621	if hcode==	146	;
replace regional_lh1990_benefit_pc2=	3890.95857	if hcode==	172	;
replace regional_lh1990_benefit_pc2=	3683.485381	if hcode==	174	;
replace regional_lh1990_benefit_pc2=	1566.899335	if hcode==	178	;
replace regional_lh1990_benefit_pc2=	1475.282831	if hcode==	182	;
replace regional_lh1990_benefit_pc2=	2251.335782	if hcode==	184	;
gen lregional_lh1990_benefit_pc2=log(regional_lh1990_benefit_pc2)		;
gen res_lregional_lh1990_benefit_pc2=restrict*lregional_lh1990_benefit_pc2;

*****************************************************;
******************interaction terms *****************;
****************************************************;


gen ps_h_l_new =ps_h_l2000_new - ps_h_l1990_new ;

gen res_lh1990=restrict*lh1990;
gen res_ps_mig1990low_new=restrict*ps_mig1990low_new;
gen res_ps_mig1990med_new=restrict*ps_mig1990med_new;
gen res_ps_mig1990high_new=restrict*ps_mig1990high_new;
gen res_lhdomestic90low=restrict*lhdomestic90low;
gen res_lhdomestic90med=restrict*lhdomestic90med;
gen res_lhdomestic90high=restrict*lhdomestic90high;

gen fre_lhdomestic90high=Free*lhdomestic90high;
gen fre_lhdomestic90med=Free*lhdomestic90med;
gen fre_lhdomestic90low=Free*lhdomestic90low;
gen res_high_lh1990=res_lhdomestic90high*lh1990;

gen hdomes90high_low=lhdomestic90high/lhdomestic90low;
gen hdomes90med_low=lhdomestic90med/lhdomestic90low;
gen fre_hdomes90high_low=Free*hdomes90high_low;
gen fre_hdomes90med_low=Free*hdomes90med_low;

gen hdomes90high_low_benefits=hdomes90high_low*lh1990;
gen hdomes90med_low_benefits=hdomes90med_low*lh1990;
gen fre_hdomes90high_low_benefits=Free*hdomes90high_low_benefits;
gen fre_hdomes90med_low_benefits=Free*hdomes90med_low_benefits;

gen res_comlang=restrict*comlang;
gen res_distance=restrict*distance;
gen res_h_rgdpwok1990=restrict*h_rgdpwok1990;
gen res_s_rgdpwok1990=restrict*s_rgdpwok1990;
gen res_h1990_rgdpch=restrict*h1990_rgdpch;
gen res_s1990_rgdpch=restrict*s1990_rgdpch;

gen ldistance=log(distance);
gen lh_rgdpwok1990=log(h_rgdpwok1990);
gen ls_rgdpwok1990=log(s_rgdpwok1990);
gen hl1990_rgdpch=log(h1990_rgdpch);
gen sl1990_rgdpch=log(s1990_rgdpch);

gen res_ldistance=restrict*ldistance;
gen res_lh_rgdpwok1990=restrict*lh_rgdpwok1990;
gen res_ls_rgdpwok1990=restrict*ls_rgdpwok1990;
gen res_hl1990_rgdpch=restrict*hl1990_rgdpch;
gen res_sl1990_rgdpch=restrict*sl1990_rgdpch;

gen res_lh_benefits80_85=restrict*lh_benefits80_85;
gen res_lh_benefits80_90=restrict*lh_benefits80_90;
gen res_lh_benefits80_95=restrict*lh_benefits80_95;
gen res_lh_benefits80_00=restrict*lh_benefits80_00;
gen res_lh_benefits80_05=restrict*lh_benefits80_05;


gen h_q5_3=(h1990_iq5/h1990_iq3);
gen h_q5_1=(h1990_iq5/h1990_iq1);
gen hs_domestic_high_low= (lhdomestic00high- lhdomestic00low)/( ls_high2000_new- ls_low2000_new);



**************************************************;
***************** adding benefits components******;
**************************************************;

gen hben_almp80=.				;
gen hben_almp85=.				;
gen hben_almp90=.				;
gen hben_almp95=.				;
gen hben_almp00=.				;
replace hben_almp80=.		if hcode==	122	;
replace hben_almp80=	.	if hcode==	124	;
replace hben_almp80=	.	if hcode==	128	;
replace hben_almp80=	128.60	if hcode==	172	;
replace hben_almp80=	.	if hcode==	132	;
replace hben_almp80=	.	if hcode==	134	;
replace hben_almp80=	.	if hcode==	174	;
replace hben_almp80=	.	if hcode==	178	;
replace hben_almp80=	.	if hcode==	136	;
replace hben_almp80=	104.80	if hcode==	138	;
replace hben_almp80=	.	if hcode==	142	;
replace hben_almp80=	.	if hcode==	182	;
replace hben_almp80=	22.70	if hcode==	184	;
replace hben_almp80=	.	if hcode==	144	;
replace hben_almp80=	.	if hcode==	146	;
replace hben_almp80=	91.10	if hcode==	112	;
replace hben_almp85=	57.90	if hcode==	122	;
replace hben_almp85=	233.20	if hcode==	124	;
replace hben_almp85=	.	if hcode==	128	;
replace hben_almp85=	137.40	if hcode==	172	;
replace hben_almp85=	113.50	if hcode==	132	;
replace hben_almp85=	86.10	if hcode==	134	;
replace hben_almp85=	22.70	if hcode==	174	;
replace hben_almp85=	130.50	if hcode==	178	;
replace hben_almp85=	.	if hcode==	136	;
replace hben_almp85=	260.10	if hcode==	138	;
replace hben_almp85=	147.20	if hcode==	142	;
replace hben_almp85=	.	if hcode==	182	;
replace hben_almp85=	44.10	if hcode==	184	;
replace hben_almp85=	441.20	if hcode==	144	;
replace hben_almp85=	50.60	if hcode==	146	;
replace hben_almp85=	126.90	if hcode==	112	;
replace hben_almp90=	74.80	if hcode==	122	;
replace hben_almp90=	250.30	if hcode==	124	;
replace hben_almp90=	172.50	if hcode==	128	;
replace hben_almp90=	185.00	if hcode==	172	;
replace hben_almp90=	156.90	if hcode==	132	;
replace hben_almp90=	172.60	if hcode==	134	;
replace hben_almp90=	28.60	if hcode==	174	;
replace hben_almp90=	166.70	if hcode==	178	;
replace hben_almp90=	50.60	if hcode==	136	;
replace hben_almp90=	290.70	if hcode==	138	;
replace hben_almp90=	237.50	if hcode==	142	;
replace hben_almp90=	63.00	if hcode==	182	;
replace hben_almp90=	130.50	if hcode==	184	;
replace hben_almp90=	385.10	if hcode==	144	;
replace hben_almp90=	64.60	if hcode==	146	;
replace hben_almp90=	117.50	if hcode==	112	;
replace hben_almp95=	94.90	if hcode==	122	;
replace hben_almp95=	295.40	if hcode==	124	;
replace hben_almp95=	487.10	if hcode==	128	;
replace hben_almp95=	291.40	if hcode==	172	;
replace hben_almp95=	267.70	if hcode==	132	;
replace hben_almp95=	281.30	if hcode==	134	;
replace hben_almp95=	63.40	if hcode==	174	;
replace hben_almp95=	258.00	if hcode==	178	;
replace hben_almp95=	62.20	if hcode==	136	;
replace hben_almp95=	338.40	if hcode==	138	;
replace hben_almp95=	386.50	if hcode==	142	;
replace hben_almp95=	70.90	if hcode==	182	;
replace hben_almp95=	76.10	if hcode==	184	;
replace hben_almp95=	514.40	if hcode==	144	;
replace hben_almp95=	136.30	if hcode==	146	;
replace hben_almp95=	92.90	if hcode==	112	;
replace hben_almp00=	150.70	if hcode==	122	;
replace hben_almp00=	297.00	if hcode==	124	;
replace hben_almp00=	582.90	if hcode==	128	;
replace hben_almp00=	228.60	if hcode==	172	;
replace hben_almp00=	301.10	if hcode==	132	;
replace hben_almp00=	307.50	if hcode==	134	;
replace hben_almp00=	44.60	if hcode==	174	;
replace hben_almp00=	272.20	if hcode==	178	;
replace hben_almp00=	143.50	if hcode==	136	;
replace hben_almp00=	442.60	if hcode==	138	;
replace hben_almp00=	219.90	if hcode==	142	;
replace hben_almp00=	104.00	if hcode==	182	;
replace hben_almp00=	142.90	if hcode==	184	;
replace hben_almp00=	487.00	if hcode==	144	;
replace hben_almp00=	173.50	if hcode==	146	;
replace hben_almp00=	88.60	if hcode==	112	;

gen lhben_almp80=log(hben_almp80);
gen lhben_almp85=log(hben_almp85);
gen lhben_almp90=log(hben_almp90);
gen lhben_almp95=log(hben_almp95);
gen lhben_almp00=log(hben_almp00);

gen res_lhben_almp80=restrict*lhben_almp80;
gen res_lhben_almp85=restrict*lhben_almp85;
gen res_lhben_almp90=restrict*lhben_almp90;
gen res_lhben_almp95=restrict*lhben_almp95;
gen res_lhben_almp00=restrict*lhben_almp00;




gen hben_family80=.				;
gen hben_family85=.				;
gen hben_family90=.				;
gen hben_family95=.				;
gen hben_family00=.				;
replace hben_family80=	605.90	if hcode==	122	;
replace hben_family80=	567.20	if hcode==	124	;
replace hben_family80=	528.50	if hcode==	128	;
replace hben_family80=	313.80	if hcode==	172	;
replace hben_family80=	437.90	if hcode==	132	;
replace hben_family80=	325.80	if hcode==	134	;
replace hben_family80=	47.10	if hcode==	174	;
replace hben_family80=	123.10	if hcode==	178	;
replace hben_family80=	187.10	if hcode==	136	;
replace hben_family80=	481.10	if hcode==	138	;
replace hben_family80=	387.60	if hcode==	142	;
replace hben_family80=	64.50	if hcode==	182	;
replace hben_family80=	61.10	if hcode==	184	;
replace hben_family80=	760.20	if hcode==	144	;
replace hben_family80=	257.30	if hcode==	146	;
replace hben_family80=	380.80	if hcode==	112	;
replace hben_family85=	580.90	if hcode==	122	;
replace hben_family85=	515.30	if hcode==	124	;
replace hben_family85=	562.90	if hcode==	128	;
replace hben_family85=	481.70	if hcode==	172	;
replace hben_family85=	509.10	if hcode==	132	;
replace hben_family85=	259.90	if hcode==	134	;
replace hben_family85=	47.60	if hcode==	174	;
replace hben_family85=	175.50	if hcode==	178	;
replace hben_family85=	170.60	if hcode==	136	;
replace hben_family85=	426.90	if hcode==	138	;
replace hben_family85=	469.50	if hcode==	142	;
replace hben_family85=	61.90	if hcode==	182	;
replace hben_family85=	35.50	if hcode==	184	;
replace hben_family85=	872.30	if hcode==	144	;
replace hben_family85=	262.10	if hcode==	146	;
replace hben_family85=	415.30	if hcode==	112	;
replace hben_family90=	603.10	if hcode==	122	;
replace hben_family90=	515.40	if hcode==	124	;
replace hben_family90=	752.00	if hcode==	128	;
replace hben_family90=	697.80	if hcode==	172	;
replace hben_family90=	540.60	if hcode==	132	;
replace hben_family90=	331.80	if hcode==	134	;
replace hben_family90=	104.20	if hcode==	174	;
replace hben_family90=	244.30	if hcode==	178	;
replace hben_family90=	166.70	if hcode==	136	;
replace hben_family90=	381.70	if hcode==	138	;
replace hben_family90=	727.30	if hcode==	142	;
replace hben_family90=	94.40	if hcode==	182	;
replace hben_family90=	53.50	if hcode==	184	;
replace hben_family90=	1039.40	if hcode==	144	;
replace hben_family90=	303.20	if hcode==	146	;
replace hben_family90=	403.00	if hcode==	112	;
replace hben_family95=	776.40	if hcode==	122	;
replace hben_family95=	552.40	if hcode==	124	;
replace hben_family95=	979.60	if hcode==	128	;
replace hben_family95=	835.10	if hcode==	172	;
replace hben_family95=	609.50	if hcode==	132	;
replace hben_family95=	452.70	if hcode==	134	;
replace hben_family95=	165.60	if hcode==	174	;
replace hben_family95=	324.70	if hcode==	178	;
replace hben_family95=	129.20	if hcode==	136	;
replace hben_family95=	328.30	if hcode==	138	;
replace hben_family95=	1101.70	if hcode==	142	;
replace hben_family95=	104.70	if hcode==	182	;
replace hben_family95=	74.00	if hcode==	184	;
replace hben_family95=	894.40	if hcode==	144	;
replace hben_family95=	337.60	if hcode==	146	;
replace hben_family95=	528.40	if hcode==	112	;
replace hben_family00=	811.20	if hcode==	122	;
replace hben_family00=	710.10	if hcode==	124	;
replace hben_family00=	886.70	if hcode==	128	;
replace hben_family00=	775.30	if hcode==	172	;
replace hben_family00=	760.60	if hcode==	132	;
replace hben_family00=	488.60	if hcode==	134	;
replace hben_family00=	186.30	if hcode==	174	;
replace hben_family00=	521.20	if hcode==	178	;
replace hben_family00=	294.10	if hcode==	136	;
replace hben_family00=	427.50	if hcode==	138	;
replace hben_family00=	1100.20	if hcode==	142	;
replace hben_family00=	174.50	if hcode==	182	;
replace hben_family00=	205.60	if hcode==	184	;
replace hben_family00=	803.50	if hcode==	144	;
replace hben_family00=	404.30	if hcode==	146	;
replace hben_family00=	707.50	if hcode==	112	;

gen lhben_family80=log(hben_family80)				;
gen lhben_family85=log(hben_family85)				;
gen lhben_family90=log(hben_family90)				;
gen lhben_family95=log(hben_family95)				;
gen lhben_family00=log(hben_family00)				;

gen res_lhben_family80=restrict*lhben_family80;
gen res_lhben_family85=restrict*lhben_family85;
gen res_lhben_family90=restrict*lhben_family90;
gen res_lhben_family95=restrict*lhben_family95;
gen res_lhben_family00=restrict*lhben_family00;



gen hben_health80=.				;
gen hben_health85=.				;
gen hben_health90=.				;
gen hben_health95=.				;
gen hben_health00=.				;
replace hben_health80=	986.9	if hcode==	122	;
replace hben_health80=	990.1	if hcode==	124	;
replace hben_health80=	1049.2	if hcode==	128	;
replace hben_health80=	842.4	if hcode==	172	;
replace hben_health80=	1014.2	if hcode==	132	;
replace hben_health80=	1073.3	if hcode==	134	;
replace hben_health80=	495.9	if hcode==	174	;
replace hben_health80=	767.0	if hcode==	178	;
replace hben_health80=	958.0	if hcode==	136	;
replace hben_health80=	989.1	if hcode==	138	;
replace hben_health80=	1048.9	if hcode==	142	;
replace hben_health80=	328.6	if hcode==	182	;
replace hben_health80=	548.1	if hcode==	184	;
replace hben_health80=	1609.1	if hcode==	144	;
replace hben_health80=	899.5	if hcode==	146	;
replace hben_health80=	815.0	if hcode==	112	;
replace hben_health85=	1012.7	if hcode==	122	;
replace hben_health85=	1133.9	if hcode==	124	;
replace hben_health85=	1097.6	if hcode==	128	;
replace hben_health85=	1052.1	if hcode==	172	;
replace hben_health85=	1191.9	if hcode==	132	;
replace hben_health85=	1186.5	if hcode==	134	;
replace hben_health85=	674.0	if hcode==	174	;
replace hben_health85=	703.1	if hcode==	178	;
replace hben_health85=	1001.1	if hcode==	136	;
replace hben_health85=	1030.9	if hcode==	138	;
replace hben_health85=	1115.2	if hcode==	142	;
replace hben_health85=	308.7	if hcode==	182	;
replace hben_health85=	588.7	if hcode==	184	;
replace hben_health85=	1639.2	if hcode==	144	;
replace hben_health85=	1046.9	if hcode==	146	;
replace hben_health85=	894.8	if hcode==	112	;
replace hben_health90=	1263.6	if hcode==	122	;
replace hben_health90=	1473.5	if hcode==	124	;
replace hben_health90=	1081.7	if hcode==	128	;
replace hben_health90=	1365.6	if hcode==	172	;
replace hben_health90=	1387.9	if hcode==	132	;
replace hben_health90=	1270.1	if hcode==	134	;
replace hben_health90=	546.4	if hcode==	174	;
replace hben_health90=	684.3	if hcode==	178	;
replace hben_health90=	1343.7	if hcode==	136	;
replace hben_health90=	1231.2	if hcode==	138	;
replace hben_health90=	1143.4	if hcode==	142	;
replace hben_health90=	505.3	if hcode==	182	;
replace hben_health90=	857.7	if hcode==	184	;
replace hben_health90=	1743.1	if hcode==	144	;
replace hben_health90=	1179.5	if hcode==	146	;
replace hben_health90=	1034.2	if hcode==	112	;
replace hben_health95=	1503.9	if hcode==	122	;
replace hben_health95=	1574.9	if hcode==	124	;
replace hben_health95=	1165.3	if hcode==	128	;
replace hben_health95=	1167.9	if hcode==	172	;
replace hben_health95=	1689.1	if hcode==	132	;
replace hben_health95=	1928.1	if hcode==	134	;
replace hben_health95=	712.3	if hcode==	174	;
replace hben_health95=	924.6	if hcode==	178	;
replace hben_health95=	1197.2	if hcode==	136	;
replace hben_health95=	1467.7	if hcode==	138	;
replace hben_health95=	1346.9	if hcode==	142	;
replace hben_health95=	692.2	if hcode==	182	;
replace hben_health95=	956.6	if hcode==	184	;
replace hben_health95=	1476.8	if hcode==	144	;
replace hben_health95=	1357.3	if hcode==	146	;
replace hben_health95=	1286.8	if hcode==	112	;
replace hben_health00=	1888.7	if hcode==	122	;
replace hben_health00=	1808.5	if hcode==	124	;
replace hben_health00=	1465.6	if hcode==	128	;
replace hben_health00=	1316.3	if hcode==	172	;
replace hben_health00=	1836.3	if hcode==	132	;
replace hben_health00=	1993.6	if hcode==	134	;
replace hben_health00=	869.5	if hcode==	174	;
replace hben_health00=	1320.6	if hcode==	178	;
replace hben_health00=	1494.8	if hcode==	136	;
replace hben_health00=	1474.5	if hcode==	138	;
replace hben_health00=	1784.4	if hcode==	142	;
replace hben_health00=	1095.2	if hcode==	182	;
replace hben_health00=	1099.8	if hcode==	184	;
replace hben_health00=	1745.0	if hcode==	144	;
replace hben_health00=	1621.4	if hcode==	146	;
replace hben_health00=	1493.3	if hcode==	112	;

gen lhben_health80=log(hben_health80)				;
gen lhben_health85=log(hben_health85)				;
gen lhben_health90=log(hben_health90)				;
gen lhben_health95=log(hben_health95)				;
gen lhben_health00=log(hben_health00)				;

gen res_lhben_health80=restrict*lhben_health80;
gen res_lhben_health85=restrict*lhben_health85;
gen res_lhben_health90=restrict*lhben_health90;
gen res_lhben_health95=restrict*lhben_health95;
gen res_lhben_health00=restrict*lhben_health00;




gen hben_house80=.				;
gen hben_house85=.				;
gen hben_house90=.				;
gen hben_house95=.				;
gen hben_house00=.				;
replace hben_house80=	18.7	if hcode==	122	;
replace hben_house80=	.	if hcode==	124	;
replace hben_house80=	71.9	if hcode==	128	;
replace hben_house80=	35.0	if hcode==	172	;
replace hben_house80=	75.3	if hcode==	132	;
replace hben_house80=	19.5	if hcode==	134	;
replace hben_house80=	9.8	if hcode==	174	;
replace hben_house80=	79.6	if hcode==	178	;
replace hben_house80=	0.8	if hcode==	136	;
replace hben_house80=	49.9	if hcode==	138	;
replace hben_house80=	88.5	if hcode==	142	;
replace hben_house80=	0.0	if hcode==	182	;
replace hben_house80=	0.0	if hcode==	184	;
replace hben_house80=	211.1	if hcode==	144	;
replace hben_house80=	23.3	if hcode==	146	;
replace hben_house80=	22.5	if hcode==	112	;
replace hben_house85=	31.4	if hcode==	122	;
replace hben_house85=	.	if hcode==	124	;
replace hben_house85=	99.5	if hcode==	128	;
replace hben_house85=	32.8	if hcode==	172	;
replace hben_house85=	130.2	if hcode==	132	;
replace hben_house85=	22.8	if hcode==	134	;
replace hben_house85=	28.9	if hcode==	174	;
replace hben_house85=	113.4	if hcode==	178	;
replace hben_house85=	1.4	if hcode==	136	;
replace hben_house85=	61.2	if hcode==	138	;
replace hben_house85=	37.6	if hcode==	142	;
replace hben_house85=	0.1	if hcode==	182	;
replace hben_house85=	2.3	if hcode==	184	;
replace hben_house85=	138.1	if hcode==	144	;
replace hben_house85=	18.7	if hcode==	146	;
replace hben_house85=	236.4	if hcode==	112	;
replace hben_house90=	22.7	if hcode==	122	;
replace hben_house90=	.	if hcode==	124	;
replace hben_house90=	149.0	if hcode==	128	;
replace hben_house90=	39.3	if hcode==	172	;
replace hben_house90=	162.2	if hcode==	132	;
replace hben_house90=	29.1	if hcode==	134	;
replace hben_house90=	66.9	if hcode==	174	;
replace hben_house90=	75.9	if hcode==	178	;
replace hben_house90=	1.6	if hcode==	136	;
replace hben_house90=	75.1	if hcode==	138	;
replace hben_house90=	40.6	if hcode==	142	;
replace hben_house90=	0.8	if hcode==	182	;
replace hben_house90=	18.1	if hcode==	184	;
replace hben_house90=	151.6	if hcode==	144	;
replace hben_house90=	34.6	if hcode==	146	;
replace hben_house90=	266.5	if hcode==	112	;
replace hben_house95=	18.1	if hcode==	122	;
replace hben_house95=	.	if hcode==	124	;
replace hben_house95=	193.7	if hcode==	128	;
replace hben_house95=	94.7	if hcode==	172	;
replace hben_house95=	207.7	if hcode==	132	;
replace hben_house95=	38.5	if hcode==	134	;
replace hben_house95=	73.6	if hcode==	174	;
replace hben_house95=	89.6	if hcode==	178	;
replace hben_house95=	1.7	if hcode==	136	;
replace hben_house95=	98.8	if hcode==	138	;
replace hben_house95=	60.0	if hcode==	142	;
replace hben_house95=	0.6	if hcode==	182	;
replace hben_house95=	40.1	if hcode==	184	;
replace hben_house95=	259.0	if hcode==	144	;
replace hben_house95=	38.8	if hcode==	146	;
replace hben_house95=	407.5	if hcode==	112	;
replace hben_house00=	26.0	if hcode==	122	;
replace hben_house00=	12.4	if hcode==	124	;
replace hben_house00=	190.8	if hcode==	128	;
replace hben_house00=	90.8	if hcode==	172	;
replace hben_house00=	220.7	if hcode==	132	;
replace hben_house00=	51.5	if hcode==	134	;
replace hben_house00=	128.5	if hcode==	174	;
replace hben_house00=	131.8	if hcode==	178	;
replace hben_house00=	2.6	if hcode==	136	;
replace hben_house00=	108.6	if hcode==	138	;
replace hben_house00=	58.7	if hcode==	142	;
replace hben_house00=	0.4	if hcode==	182	;
replace hben_house00=	35.1	if hcode==	184	;
replace hben_house00=	172.4	if hcode==	144	;
replace hben_house00=	43.2	if hcode==	146	;
replace hben_house00=	375.3	if hcode==	112	;

gen lhben_house80=log(hben_house80)				;
gen lhben_house85=log(hben_house85)				;
gen lhben_house90=log(hben_house90)				;
gen lhben_house95=log(hben_house95)				;
gen lhben_house00=log(hben_house00)				;

gen res_lhben_house80=restrict*lhben_house80;
gen res_lhben_house85=restrict*lhben_house85;
gen res_lhben_house90=restrict*lhben_house90;
gen res_lhben_house95=restrict*lhben_house95;
gen res_lhben_house00=restrict*lhben_house00;





gen hben_oldage80=.				;
gen hben_oldage85=.				;
gen hben_oldage90=.				;
gen hben_oldage95=.				;
gen hben_oldage00=.				;
replace hben_oldage80=	1920.3	if hcode==	122	;
replace hben_oldage80=	1126.3	if hcode==	124	;
replace hben_oldage80=	1316.4	if hcode==	128	;
replace hben_oldage80=	867.9	if hcode==	172	;
replace hben_oldage80=	1377.0	if hcode==	132	;
replace hben_oldage80=	1569.3	if hcode==	134	;
replace hben_oldage80=	695.7	if hcode==	174	;
replace hben_oldage80=	505.9	if hcode==	178	;
replace hben_oldage80=	1251.4	if hcode==	136	;
replace hben_oldage80=	1173.0	if hcode==	138	;
replace hben_oldage80=	1094.6	if hcode==	142	;
replace hben_oldage80=	309.2	if hcode==	182	;
replace hben_oldage80=	593.4	if hcode==	184	;
replace hben_oldage80=	1502.8	if hcode==	144	;
replace hben_oldage80=	1402.3	if hcode==	146	;
replace hben_oldage80=	697.7	if hcode==	112	;
replace hben_oldage85=	2263.5	if hcode==	122	;
replace hben_oldage85=	1257.3	if hcode==	124	;
replace hben_oldage85=	1485.9	if hcode==	128	;
replace hben_oldage85=	1326.4	if hcode==	172	;
replace hben_oldage85=	1636.5	if hcode==	132	;
replace hben_oldage85=	1706.7	if hcode==	134	;
replace hben_oldage85=	1063.8	if hcode==	174	;
replace hben_oldage85=	578.4	if hcode==	178	;
replace hben_oldage85=	1688.1	if hcode==	136	;
replace hben_oldage85=	1183.3	if hcode==	138	;
replace hben_oldage85=	1365.1	if hcode==	142	;
replace hben_oldage85=	333.7	if hcode==	182	;
replace hben_oldage85=	779.7	if hcode==	184	;
replace hben_oldage85=	1750.8	if hcode==	144	;
replace hben_oldage85=	1534.1	if hcode==	146	;
replace hben_oldage85=	812.8	if hcode==	112	;
replace hben_oldage90=	2668.9	if hcode==	122	;
replace hben_oldage90=	1494.7	if hcode==	124	;
replace hben_oldage90=	1699.9	if hcode==	128	;
replace hben_oldage90=	1533.8	if hcode==	172	;
replace hben_oldage90=	1996.3	if hcode==	132	;
replace hben_oldage90=	1890.3	if hcode==	134	;
replace hben_oldage90=	1438.0	if hcode==	174	;
replace hben_oldage90=	508.8	if hcode==	178	;
replace hben_oldage90=	1817.5	if hcode==	136	;
replace hben_oldage90=	1452.4	if hcode==	138	;
replace hben_oldage90=	1886.8	if hcode==	142	;
replace hben_oldage90=	547.7	if hcode==	182	;
replace hben_oldage90=	1204.2	if hcode==	184	;
replace hben_oldage90=	2012.3	if hcode==	144	;
replace hben_oldage90=	1632.0	if hcode==	146	;
replace hben_oldage90=	1032.2	if hcode==	112	;
replace hben_oldage95=	3129.0	if hcode==	122	;
replace hben_oldage95=	1707.1	if hcode==	124	;
replace hben_oldage95=	2133.8	if hcode==	128	;
replace hben_oldage95=	1757.4	if hcode==	172	;
replace hben_oldage95=	2381.9	if hcode==	132	;
replace hben_oldage95=	2452.6	if hcode==	134	;
replace hben_oldage95=	1459.4	if hcode==	174	;
replace hben_oldage95=	552.6	if hcode==	178	;
replace hben_oldage95=	2182.9	if hcode==	136	;
replace hben_oldage95=	1374.6	if hcode==	138	;
replace hben_oldage95=	2192.3	if hcode==	142	;
replace hben_oldage95=	884.8	if hcode==	182	;
replace hben_oldage95=	1475.3	if hcode==	184	;
replace hben_oldage95=	2321.1	if hcode==	144	;
replace hben_oldage95=	1891.2	if hcode==	146	;
replace hben_oldage95=	1253.0	if hcode==	112	;
replace hben_oldage00=	3582.4	if hcode==	122	;
replace hben_oldage00=	1906.2	if hcode==	124	;
replace hben_oldage00=	2033.8	if hcode==	128	;
replace hben_oldage00=	1927.3	if hcode==	172	;
replace hben_oldage00=	2648.5	if hcode==	132	;
replace hben_oldage00=	2786.1	if hcode==	134	;
replace hben_oldage00=	1857.1	if hcode==	174	;
replace hben_oldage00=	740.7	if hcode==	178	;
replace hben_oldage00=	2861.7	if hcode==	136	;
replace hben_oldage00=	1548.1	if hcode==	138	;
replace hben_oldage00=	2356.6	if hcode==	142	;
replace hben_oldage00=	1179.2	if hcode==	182	;
replace hben_oldage00=	1756.3	if hcode==	184	;
replace hben_oldage00=	2552.6	if hcode==	144	;
replace hben_oldage00=	2030.8	if hcode==	146	;
replace hben_oldage00=	1443.0	if hcode==	112	;

gen lhben_oldage80=log(hben_oldage80)				;
gen lhben_oldage85=log(hben_oldage85)				;
gen lhben_oldage90=log(hben_oldage90)				;
gen lhben_oldage95=log(hben_oldage95)				;
gen lhben_oldage00=log(hben_oldage00)				;

gen res_lhben_oldage80=restrict*lhben_oldage80;
gen res_lhben_oldage85=restrict*lhben_oldage85;
gen res_lhben_oldage90=restrict*lhben_oldage90;
gen res_lhben_oldage95=restrict*lhben_oldage95;
gen res_lhben_oldage00=restrict*lhben_oldage00;





gen hben_unemp80=.				;
gen hben_unemp85=.				;
gen hben_unemp90=.				;
gen hben_unemp95=.				;
gen hben_unemp00=.				;
replace hben_unemp80=	77.20	if hcode==	122	;
replace hben_unemp80=	460.10	if hcode==	124	;
replace hben_unemp80=	902.80	if hcode==	128	;
replace hben_unemp80=	109.70	if hcode==	172	;
replace hben_unemp80=	.	if hcode==	132	;
replace hben_unemp80=	79.20	if hcode==	134	;
replace hben_unemp80=	33.50	if hcode==	174	;
replace hben_unemp80=	.	if hcode==	178	;
replace hben_unemp80=	101.20	if hcode==	136	;
replace hben_unemp80=	312.70	if hcode==	138	;
replace hben_unemp80=	76.30	if hcode==	142	;
replace hben_unemp80=	27.60	if hcode==	182	;
replace hben_unemp80=	254.30	if hcode==	184	;
replace hben_unemp80=	71.60	if hcode==	144	;
replace hben_unemp80=	18.30	if hcode==	146	;
replace hben_unemp80=	201.10	if hcode==	112	;
replace hben_unemp85=	190.20	if hcode==	122	;
replace hben_unemp85=	649.30	if hcode==	124	;
replace hben_unemp85=	920.40	if hcode==	128	;
replace hben_unemp85=	243.00	if hcode==	172	;
replace hben_unemp85=	439.50	if hcode==	132	;
replace hben_unemp85=	164.70	if hcode==	134	;
replace hben_unemp85=	46.10	if hcode==	174	;
replace hben_unemp85=	414.00	if hcode==	178	;
replace hben_unemp85=	244.90	if hcode==	136	;
replace hben_unemp85=	660.40	if hcode==	138	;
replace hben_unemp85=	119.20	if hcode==	142	;
replace hben_unemp85=	28.00	if hcode==	182	;
replace hben_unemp85=	369.60	if hcode==	184	;
replace hben_unemp85=	183.50	if hcode==	144	;
replace hben_unemp85=	65.90	if hcode==	146	;
replace hben_unemp85=	374.70	if hcode==	112	;
replace hben_unemp90=	214.50	if hcode==	122	;
replace hben_unemp90=	657.60	if hcode==	124	;
replace hben_unemp90=	968.60	if hcode==	128	;
replace hben_unemp90=	238.20	if hcode==	172	;
replace hben_unemp90=	362.50	if hcode==	132	;
replace hben_unemp90=	170.70	if hcode==	134	;
replace hben_unemp90=	61.90	if hcode==	174	;
replace hben_unemp90=	265.70	if hcode==	178	;
replace hben_unemp90=	131.70	if hcode==	136	;
replace hben_unemp90=	576.10	if hcode==	138	;
replace hben_unemp90=	281.80	if hcode==	142	;
replace hben_unemp90=	41.20	if hcode==	182	;
replace hben_unemp90=	526.80	if hcode==	184	;
replace hben_unemp90=	203.00	if hcode==	144	;
replace hben_unemp90=	33.50	if hcode==	146	;
replace hben_unemp90=	151.50	if hcode==	112	;
replace hben_unemp95=	321.60	if hcode==	122	;
replace hben_unemp95=	787.70	if hcode==	124	;
replace hben_unemp95=	1131.00	if hcode==	128	;
replace hben_unemp95=	806.60	if hcode==	172	;
replace hben_unemp95=	363.60	if hcode==	132	;
replace hben_unemp95=	391.30	if hcode==	134	;
replace hben_unemp95=	64.90	if hcode==	174	;
replace hben_unemp95=	347.40	if hcode==	178	;
replace hben_unemp95=	161.20	if hcode==	136	;
replace hben_unemp95=	701.60	if hcode==	138	;
replace hben_unemp95=	329.40	if hcode==	142	;
replace hben_unemp95=	134.20	if hcode==	182	;
replace hben_unemp95=	564.90	if hcode==	184	;
replace hben_unemp95=	537.90	if hcode==	144	;
replace hben_unemp95=	309.60	if hcode==	146	;
replace hben_unemp95=	196.70	if hcode==	112	;
replace hben_unemp00=	272.90	if hcode==	122	;
replace hben_unemp00=	776.70	if hcode==	124	;
replace hben_unemp00=	865.30	if hcode==	128	;
replace hben_unemp00=	559.70	if hcode==	172	;
replace hben_unemp00=	366.20	if hcode==	132	;
replace hben_unemp00=	400.90	if hcode==	134	;
replace hben_unemp00=	74.70	if hcode==	174	;
replace hben_unemp00=	225.20	if hcode==	178	;
replace hben_unemp00=	102.80	if hcode==	136	;
replace hben_unemp00=	371.40	if hcode==	138	;
replace hben_unemp00=	163.40	if hcode==	142	;
replace hben_unemp00=	112.30	if hcode==	182	;
replace hben_unemp00=	422.40	if hcode==	184	;
replace hben_unemp00=	384.40	if hcode==	144	;
replace hben_unemp00=	159.80	if hcode==	146	;
replace hben_unemp00=	84.90	if hcode==	112	;

gen lhben_unemp80=log(hben_unemp80)				;
gen lhben_unemp85=log(hben_unemp85)				;
gen lhben_unemp90=log(hben_unemp90)				;
gen lhben_unemp95=log(hben_unemp95)				;
gen lhben_unemp00=log(hben_unemp00)				;

gen res_lhben_unemp80=restrict*lhben_unemp80;
gen res_lhben_unemp85=restrict*lhben_unemp85;
gen res_lhben_unemp90=restrict*lhben_unemp90;
gen res_lhben_unemp95=restrict*lhben_unemp95;
gen res_lhben_unemp00=restrict*lhben_unemp00;





****************gini data relates to mid 2000;
gen h_gini00_before=.				;
replace h_gini00_before=	0.433	if hcode==	122	;
replace h_gini00_before=	0.494	if hcode==	124	;
replace h_gini00_before=	0.417	if hcode==	128	;
replace h_gini00_before=	0.386	if hcode==	172	;
replace h_gini00_before=	0.482	if hcode==	132	;
replace h_gini00_before=	0.507	if hcode==	134	;
replace h_gini00_before=	0.454	if hcode==	174	;
replace h_gini00_before=	0.416	if hcode==	178	;
replace h_gini00_before=	0.557	if hcode==	136	;
replace h_gini00_before=	0.423	if hcode==	138	;
replace h_gini00_before=	0.433	if hcode==	142	;
replace h_gini00_before=	0.542	if hcode==	182	;
replace h_gini00_before=	0.338	if hcode==	184	;
replace h_gini00_before=	0.432	if hcode==	144	;
replace h_gini00_before=	0.352	if hcode==	146	;
replace h_gini00_before=	0.46	if hcode==	112	;
gen res_h_gini00_before=restrict*h_gini00_before;

gen h_gini00_after=.				;
replace h_gini00_after=	0.3	if hcode==	122	;
replace h_gini00_after=	0.3	if hcode==	124	;
replace h_gini00_after=	0.2	if hcode==	128	;
replace h_gini00_after=	0.3	if hcode==	172	;
replace h_gini00_after=	0.3	if hcode==	132	;
replace h_gini00_after=	0.3	if hcode==	134	;
replace h_gini00_after=	0.3	if hcode==	174	;
replace h_gini00_after=	0.3	if hcode==	178	;
replace h_gini00_after=	0.4	if hcode==	136	;
replace h_gini00_after=	0.3	if hcode==	138	;
replace h_gini00_after=	0.3	if hcode==	142	;
replace h_gini00_after=	0.4	if hcode==	182	;
replace h_gini00_after=	0.3	if hcode==	184	;
replace h_gini00_after=	0.2	if hcode==	144	;
replace h_gini00_after=	0.3	if hcode==	146	;
replace h_gini00_after=	0.3	if hcode==	112	;
gen res_h_gini00_after=restrict*h_gini00_after;

gen h_gini00_after_before=h_gini00_after/h_gini00_before;
gen res_h_gini00_after_before=restrict*h_gini00_after_before;



*************poverty: percentage of those with 50% of median income in 2000;

gen poverty50_after00=.				;
replace poverty50_after00=	9.3	if hcode==	122	;
replace poverty50_after00=	10.4	if hcode==	124	;
replace poverty50_after00=	5.1	if hcode==	128	;
replace poverty50_after00=	6.4	if hcode==	172	;
replace poverty50_after00=	7.2	if hcode==	132	;
replace poverty50_after00=	9.2	if hcode==	134	;
replace poverty50_after00=	13.5	if hcode==	174	;
replace poverty50_after00=	15.4	if hcode==	178	;
replace poverty50_after00=	11.8	if hcode==	136	;
replace poverty50_after00=	6.8	if hcode==	138	;
replace poverty50_after00=	6.3	if hcode==	142	;
replace poverty50_after00=	13.7	if hcode==	182	;
replace poverty50_after00=	13.7	if hcode==	184	;
replace poverty50_after00=	5.3	if hcode==	144	;
replace poverty50_after00=	7.5	if hcode==	146	;
replace poverty50_after00=	10.2	if hcode==	112	;
gen poverty50_before00=.				;
replace poverty50_before00=	23.1	if hcode==	122	;
replace poverty50_before00=	35.6	if hcode==	124	;
replace poverty50_before00=	23.2	if hcode==	128	;
replace poverty50_before00=	18.0	if hcode==	172	;
replace poverty50_before00=	33.0	if hcode==	132	;
replace poverty50_before00=	31.1	if hcode==	134	;
replace poverty50_before00=	32.2	if hcode==	174	;
replace poverty50_before00=	25.7	if hcode==	178	;
replace poverty50_before00=	31.1	if hcode==	136	;
replace poverty50_before00=	23.6	if hcode==	138	;
replace poverty50_before00=	22.6	if hcode==	142	;
replace poverty50_before00=	24.1	if hcode==	182	;
replace poverty50_before00=	17.9	if hcode==	184	;
replace poverty50_before00=	27.0	if hcode==	144	;
replace poverty50_before00=	16.5	if hcode==	146	;
replace poverty50_before00=	27.8	if hcode==	112	;
gen poverty50_before_after00=poverty50_before00/poverty50_after00				;

gen res_poverty50_after00=restrict*poverty50_after00;
gen res_poverty50_before00=restrict*poverty50_before00;
gen res_poverty50_before_after00=restrict*poverty50_before_after00;



gen lhben_oldage80_00= log(( hben_oldage80+ hben_oldage85+  hben_oldage90 + hben_oldage95+  hben_oldage00)/5);
gen res_lhben_oldage80_00=restrict*lhben_oldage80_00;

gen res_lben_h=restrict*lben_h;

replace h1990_unemp=	8.026315	if hcode==	112	;
replace h1990_unemp=	2.662783	if hcode==	122	;
replace h1990_unemp=	7.511691	if hcode==	124	;
replace h1990_unemp=	5.624032	if hcode==	128	;
replace h1990_unemp=	7.607189	if hcode==	132	;
replace h1990_unemp=	5.566668	if hcode==	134	;
replace h1990_unemp=	7.23045	if hcode==	136	;
replace h1990_unemp=	6.120454	if hcode==	138	;
replace h1990_unemp=	2.562846	if hcode==	142	;
replace h1990_unemp=	2.25335	if hcode==	144	;
replace h1990_unemp=	0.491109	if hcode==	146	;
replace h1990_unemp=	4.796655	if hcode==	172	;
replace h1990_unemp=	3.950829	if hcode==	174	;
replace h1990_unemp=	12.40918	if hcode==	178	;
replace h1990_unemp=	6.976644	if hcode==	182	;
replace h1990_unemp=	10.80347	if hcode==	184	;
 gen res_h1990_unemp=restrict*h1990_unemp;


gen res_h_french=h_french*restrict;
gen res_h_scandinavian=h_scandinavian*restrict;
gen res_h_english=h_english*restrict;
gen res_h_german=h_german*restrict;
gen res_h_ger_fre=h_ger_fre*restrict;

save C:\Alon\CR_migration\CR_database.dta, replace;


